// pages/login-component/loginPage/loginPage.js
const app = getApp()
var MD5 = require('/helper/common/md5.js');
var Utils = require('/helper/common/util.js');
import LoginApi from "/helper/network/loginApi";
Component({
  /**
   * 组件的属性列表
   */
  properties: {
    systemName: {
      type: String
    },
    systemID: {
      type: String
    },
    appID:{
      type: String
    },
    appSecret:{
      type: String
    },
    isUserLogout:{
      type: String
    },
    phoneType:{
      type: Number
    },
    
    systemIconUrl:{
      type: String
    },
    
  },

  /**
   * 组件的初始数据
   */
  data: {
    currentRole: 0,
    schoolInfo:[],
    schoolSelectIndex:0,
    schoolsName:[],
    schoolName:null,
    account:null,
    password:null,
    appRes:null,
    userInfo: {},
    hasUserInfo: false,
    encryptedData:null,
    iv:null,
    isFristLoad:false,
    canteenSystemInfo:null,
    schoolSearchViewTop:350,
    schoolSearchFocus:false,
    schoolItem:null,
    openID:null,
    unionID:null,
  },


  lifetimes: {
      attached: function() {
        // 在组件实例进入页面节点树时执行
        if(app.isUserLogout){
          app.isUserLogout = false;
          this.updateUnoinInfo();
          this.sendSchoolsInfoRequst(false); 
          return;
        }
         this.sendSchoolsInfoRequst(false); 
         this.getUnionIDStorage();

      },
      detached: function() {
        // 在组件实例被从页面节点树移除时执行
      },
  },

  pageLifetimes: {
    show: function() {
      // 页面被展示
     var that = this;
     wx.createSelectorQuery().select('#login-cell-school').boundingClientRect(function(res){that.setData({schoolSearchViewTop:res.top + res.height})}).exec()
    },
    hide: function() {
      // 页面被隐藏
    },
    resize: function(size) {
      // 页面尺寸变化
    }
  },

  /**
   * 组件的方法列表
   */
  methods: {
  //①获取UnionID自动登录
  getUnionIDStorage:function(){
    var that = this;
    try {
        wx.getStorage({
          key: 'unionID',
          success: function (res) {  
            if(res.data){
               console.log('缓存UnionID:',res.data)
               that.autoLoginWithUnionID(res.data)
            }else{
              that.getUserInfo();
            }
          },
          fail:function(res){
             that.getUserInfo();
          }
        })
    } catch (e) {
        that.getUserInfo();
    }
    
  },

  //② 获取wx.login获取用户信息,自动登录
  getUserInfo: function(e) {
     
      let that = this
      wx.showLoading({
        title: '请稍后',
        mask:true,
      })
      // 微信登录
      wx.login({ 
        success: res => {
          console.log(res)
          // 发送 res.code 到后台换取 openId, sessionKey, unionId 
          if (res.code) {
            console.log(res);
            that.setData({appRes:res})
            that.autoLoginCheck(res)
          } 
        },
        fail(res){
           wx.clearStorage({complete: (res) => {},});
           that.showGetUserInfoAgain('登录失败');
        }
      })
  },

  //③通过UnionID执行后台检测绑定API,获取到信息证明已绑定,直接登录
  autoLoginWithUnionID:function(unionID){
    wx.showLoading({title: '登录中...',mask:true})
    var that = this;   
    var urlParam = {
      AppID: that.properties.appID,
      BrowserInfo: "Andriod",
      LoginIP: "192.168.2.90",
      MacAddress: ' ',
      MachineType: that.properties.phoneType,
      SysTemID: that.properties.systemID,
      encryptedData:' ',
      WXName: ' ',
      WXPhoto: ' ',
      phone: "null",
      openID: " ",
      unionID: unionID
    }
    
    LoginApi.wxLoginWithUnionIDApi(urlParam).then(data => {
      wx.hideLoading();
      console.log(data);
      if (data['error'] == 0) {
        switch (data.data["state"]) {
          case 0://登录成功
            that.loginToMainPageWithData(data)
            break;
          case 1://用户未绑定微信
            this.updateUnoinInfo();
            wx.showToast({title: '请登录',icon: 'none',duration: 2000})
            break;
          case 2://登录云平台失败
            wx.showToast({title: '请求失败,请重新登录',icon: 'none',duration: 2000})
            break; 
          case 3://获取微信信息失败，一般是获取UinonID失败
            this.updateUnoinInfo();
            wx.showToast({title: '获取微信信息失败，请重新登录',icon: 'none',duration: 2000})
            break;
          case 4://找不到该学校id对应的学校
            wx.showToast({title: '获取学校信息失败,请重新登录',icon: 'none',duration: 2000})
            break;
          case 5: //其他 
            that.updateUnoinInfo();
            wx.showToast({title: '获取用户信息,请重新登录',icon: 'none',duration: 2000})
             break;
          default:
            break;
        }
      }else{
        this.updateUnoinInfo();
        wx.showToast({title: '登录失败,请重新登录',icon: 'none',duration: 2000})
      }
    }).catch(e => {
      wx.showToast({title: '请求失败,请重新登录',icon: 'none',duration: 2000})
      this.updateUnoinInfo();
    })
  },


   //④通过登录获取js_code 执行后台检测绑定API,获取到信息证明已绑定,直接登录
   autoLoginCheck:function(res){
    
    var that = this;   
    var urlParam = {
      AppID: that.properties.appID,
      BrowserInfo: "Andriod",
      LoginIP: "192.168.2.90",
      MacAddress: ' ',
      MachineType: that.properties.phoneType,
      Secret: that.properties.appSecret,
      SysTemID: this.properties.systemID,
      js_Code: res.code,
      encryptedData:' ',
      iv: ' ',
      WXName: ' ',
      WXPhoto: ' ',
      phone: "null"
    }
    
    LoginApi.wxLoginApi(urlParam).then(data => {
      wx.hideLoading();
      if (data['error'] == 0) {
        switch (data.data["state"]) {
          case 0://登录成功
            wx.setStorageSync('unionID', data.data.wxsession.unionid)
            that.loginToMainPageWithData(data)
            break;
          case 1://用户未绑定微信
            that.updateUnoinInfo();
            wx.setStorageSync('unionID', data.data.wxsession.unionid)
            wx.showToast({title: '请登录',icon: 'none',duration: 2000})
            break;
          case 2://登录云平台失败
            wx.setStorageSync('unionID', data.data.wxsession.unionid)
            wx.showToast({title: '请求失败,请重新登录',icon: 'none',duration: 2000})
            break; 
          case 3://获取微信信息失败，一般是获取UinonID失败
            this.updateUnoinInfo();
            wx.showToast({title: '获取微信信息失败，请重新登录',icon: 'none',duration: 2000})
            break;
          case 4://找不到该学校id对应的学校
            wx.setStorageSync('unionID', data.data.wxsession.unionid)
            wx.showToast({title: '获取学校信息失败,请重新登录',icon: 'none',duration: 2000})
            break;
          case 5: //其他 
            this.updateUnoinInfo();
            wx.showToast({title: '获取用户信息,请重新登录',icon: 'none',duration: 2000})
             break;
          default:
            break;
        }
      }else{
        this.updateUnoinInfo();
        wx.showToast({title:'登录失败,请重新登录',icon: 'none',duration: 2000})       
      }
    }).catch(e => {
      wx.showToast({title: '请求失败,请重新登录',icon: 'none',duration: 2000})
      this.updateUnoinInfo();
    })
  },


   //⑤手动登录
  loginAction:function(){
     var that = this;
     if (!that.data.openID || !that.data.unionID){
       wx.showToast({title:'获取用户信息失败,请稍后重试',icon: 'none',duration: 2000})
       this.updateUnoinInfo();
       return;
     }

    if(!this.data.schoolItem){
      wx.showToast({title:'请确保选择正确学校',icon: 'none',duration: 2000})
      return;
    }

     if(!this.data.account){
       wx.showToast({title:'请输入账号',icon: 'none',duration: 2000})
       return;
     }

     if(!this.data.password){
       wx.showToast({title:'请输入密码',icon: 'none',duration: 2000})
       return;
     }
    
     wx.showLoading({title: '登录中...',mask:true}) 
     var urlParam = {
       AppID: that.properties.appID,
       BrowserInfo: "Andriod",
       LoginIP: "192.168.2.90",
       MacAddress: '',
       MachineType: that.properties.phoneType,
       OpenID: that.data.openID,
       PSW:MD5.reverseMD5String(this.data.password),
       SchoolID: this.data.schoolItem.SchoolID,
       SysTemID: this.properties.systemID,
       UnionID:that.data.unionID,
       UserID: this.data.account,
       WXName: '',
       WXPhoto: '',
       phone: "null"
     }

    LoginApi.yunLoginApi(urlParam).then(data => {
       var that = this;
       wx.hideLoading();
       if (data['error'] == 0) {
         if(data.data['userInfo']){
           that.loginToMainPageWithData(data)
         } else if (data.data['msg'] == '账号密码不匹配') {
           wx.showToast({title:'账号密码不匹配,请重新输入',icon: 'none',duration: 2000})
         }else{      
           wx.showToast({title:data.data['msg'],icon: 'none',duration: 2000})         
         }
       }else{
         wx.showToast({title:'登录失败,请稍后再试',icon: 'none',duration: 2000})       
       }
     }).catch(e => {
       wx.showToast({title:'请求失败',icon: 'none',duration: 2000})       
       console.error('请求失败',e);
     })
  },
  
  //获取学校信息
  sendSchoolsInfoRequst:function(showToast){
    var that = this;
    //先获取学校缓存，再更新学校缓存
    wx.getStorage({
       key: 'schoolsInfo',
       success: function (res) {  
         var schoolsInfoArr = JSON.parse(res.data)           
         that.setData({
           schoolInfo: schoolsInfoArr,
         })
       },
    })
    LoginApi.getSchoolApi().then(data => {     
     if (data['error'] == 0) {
       var schoolNameInfo =  new Array();
       data.data.schools.forEach(item => {            
       schoolNameInfo.push(item.SchoolName)
      })
     //缓存学校信息
     var schoolsInfo = JSON.stringify(data.data.schools)
     wx.setStorage({
       key: "schoolsInfo",
       data: schoolsInfo
     })
     that.setData({
       schoolInfo:data.data.schools,
       schoolsName:schoolNameInfo
     })
      console.log(that.data.schoolsName)
     }else{
       wx.getStorage({
         key: 'schoolsInfo',
         success: function (res) {       
           var schoolsInfoArr = JSON.parse(res.data)       
           that.setData({
             schoolInfo: schoolsInfoArr,
           })
         },
       })
     }
   }).catch(e => {})
  },
  
  //更新Union信息
  updateUnoinInfo:function() {
    var that = this;
    wx.getStorage({
      key: 'openID',
      success: function (res) {  
        if(res.data){
           that.setData({openID:res.data})
        }
      }
    })
    wx.getStorage({
      key: 'unionID',
      success: function (res) {  
        if(res.data){
          that.setData({unionID:res.data})
         }
      }
    })
     
      wx.login({ 
        success: res => {
          if (res.code) {
            this.getUnionIDInfoRequest(res.code);
          } 
        },
      })
  },

  //获取UnionID
  getUnionIDInfoRequest:function(code){
      var that = this;
      console.log(code)
      var param ={
          AppID:that.properties.appID,
          js_Code:code,
          Secret:that.properties.appSecret,
          encryptedData:" ",
          iv:" ",
      }
      LoginApi.getUnionIdApi(param).then(result => {
          const {error,msg,data} = result;
          console.log(data);
            if(error == 0){
              that.setData({
                openID:data.openid,
                unionID:data.unionid
              })
              that.stroageUnionIDAndOpenID(data.unionID,data.openid);
            }   
      });
  },
  
  //缓存UnionID
  stroageUnionIDAndOpenID:function(unionID,openID){
     wx.setStorageSync('openID', openID)
     wx.setStorageSync('unionID', unionID)
  },

  //获取数据成功，登录到对应页面
  loginToMainPageWithData:function(data){  
    this.redirectToRolePage(data);
  },

  //跳转到对应界面
  redirectToRolePage:function(data){
    var that = this;
    wx.showToast({title: '登录成功',icon: 'success',duration: 1000})
    this.loginSucceed(data);
    // wx.switchTab({
    //   url: '../../../pages/APage/APage',
    // })
  },

  //学校选择操作
  schoolChooseHandler:function(sender){
    var schoolInfo = this.data.schoolInfo[sender.detail.value]
    this.setData({
      schoolName: schoolInfo.SchoolName,
      schoolSelectIndex:sender.detail.value,
    })
    console.log(this.data.schoolName);
   },
    
  schoolInfoListHandler:function() {
     this.sendSchoolsInfoRequst(true)
  },

  schoolFocusAction:function(){
      this.setData({
        schoolSearchFocus:true,
      })
  },

  schoolBlurAction:function(sender){
      console.log(sender.detail.value)
      this.setData({
        schoolSearchFocus:false,
        searchSchoolArr:[],
      })
      
      if(!this.data.schoolItem){
        this.data.schoolInfo.forEach(element => {
            if(element.SchoolName == sender.detail.value){
               this.setData({
                 schoolItem:element,
               })
               console.log(this.data.schoolItem)
            }
        });
      }
  },

  searchCellAction:function(sender){
    console.log(sender.currentTarget.dataset.item)
    this.setData({
      schoolName: sender.currentTarget.dataset.item.SchoolName,
      schoolItem:sender.currentTarget.dataset.item,
      schoolSearchFocus:false,
      searchSchoolArr:[],
    })
    console.log(this.data.schoolName);
  },

  schoolAction:function(sender){
    if(!this.data.schoolSearchFocus) return;
    console.log(sender.detail.value);
    var searchName = sender.detail.value;
    var searchSchoolArr = [];
    
    this.data.schoolInfo.forEach(element => {
        if(element.SchoolName.indexOf(searchName)>=0 && searchName.length>0){
          searchSchoolArr.push(element);
        }
    });
    this.setData({
        searchSchoolArr:searchSchoolArr,
        schoolItem:null,
    })
    console.log(searchSchoolArr);
  },
  
   //账号输入
  accountAction:function(sender){
    console.log(sender.detail.value);
    this.setData({
      account: sender.detail.value,
    });
   },
    
    //密码输入
  passwordAction:function(sender){
    console.log(sender.detail.value);
    this.setData({
      password: sender.detail.value,
    });
  },

  //获取用户信息失败,重新获取用户信息
  showGetUserInfoAgain:function(e){
    var that = this;
      wx.showModal({
        title: '提示！',
        confirmText: '重新登录',
        showCancel: true,
        content: e,
        success: function(res) {
          if (res.confirm) {
              that.getUserInfo();
          }
        }
      })
  },

   loginSucceed:function (sender) {
      console.log('登录成功')
      this.triggerEvent('loginSucceed', sender)
   },
  },

  
})
